[Telepathy-commits] [telepathy-gabble/master] tubes-channel: tube_closed_cb: fire ChannelClosed signal when a muc stream tube is closed

Guillaume Desmottes guillaume.desmottes at collabora.co.uk
Mon Feb 2 08:17:55 PST 2009


---
 src/tubes-channel.c |    7 +++++--
 1 files changed, 5 insertions(+), 2 deletions(-)

diff --git a/src/tubes-channel.c b/src/tubes-channel.c
index e349b3a..479fe03 100644
--- a/src/tubes-channel.c
+++ b/src/tubes-channel.c
@@ -464,8 +464,11 @@ tube_closed_cb (GabbleTubeIface *tube,
     }
   else
     {
-      /* FIXME: emit with the muc-factory once new API is implemented in muc
-       * tubes */
+      /* FIXME: this is a workaround while new tube API is not implemented on
+       * D-Bus tubes */
+      if (GABBLE_IS_TUBE_STREAM (tube))
+        tp_channel_manager_emit_channel_closed_for_object (
+            priv->conn->muc_factory, TP_EXPORTABLE_CHANNEL (tube));
     }
 
 }
-- 
1.5.6.5




More information about the Telepathy-commits mailing list